AGW Logo

svn SVN Revision 68881 For supertooltip

This file contains the SVN revision history for supertooltip, at revision 68881.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 17-Oct-2008 20:51:43 UTC
  • Committer: AG
  • File Size: 45578 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

  • AGW: General overhaul of the documentation, much improved. All the widgets have their own sample usage in the docs as well;

  • FlatNotebook: Added the FNB_NAV_BUTTONS_WHEN_NEEDED style, which hides the navigation left/right arrows if all tabs fit;

  • RibbonBar: - Added the EVT_RIBBONBAR_TAB_LEFT_DCLICK event, which generates a special event

    when a ribbon bar tab is double-clicked;

    • Added support for toggle buttons;
    • Improved support for ribbon panel sizers: panels with sizers should now automatically minimise at small sizes, and behave properly when popping up from a minimised state;
    • Added tooltips via SetToolTip for those buttons which have the help_string attribute set.
  • XLSGrid: a new widget was added to AGW, termed XLSGrid. It’s based on wx.grid.Grid and can be used to faithfully reproduce the appearance of a Microsoft Excel spreadsheets.


svn_diff Diff To Previous Version (68362)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/supertooltip.py       2011/07/24 21:36:47     68362
+++ wxPython/3rdParty/AGW/agw/supertooltip.py       2011/08/25 16:40:17     68881
@@ -2,7 +2,7 @@
# SUPERTOOLTIP wxPython IMPLEMENTATION
#
# Andrea Gavana, @ 07 October 2008
# Latest Revision: 22 Jul 2011, 21.00 GMT
#
#
# TODO List
@@ -26,14 +26,14 @@
# --------------------------------------------------------------------------------- #

"""
-SuperToolTip is a class that mimics the behaviour of `wx.TipWindow` and generic tooltip
+L{SuperToolTip} is a class that mimics the behaviour of `wx.TipWindow` and generic tooltip
windows, although it is a custom-drawn widget.


Description
===========

-SuperToolTip is a class that mimics the behaviour of `wx.TipWindow` and generic tooltip
+L{SuperToolTip} is a class that mimics the behaviour of `wx.TipWindow` and generic tooltip
windows, although it is a custom-drawn widget.

This class supports:
@@ -53,10 +53,50 @@
And a lot more. Check the demo for an almost complete review of the functionalities.


+Usage
+=====
+
+Usage example::
+
+    import wx
+    import wx.lib.agw.supertooltip as STT
+
+    class MyFrame(wx.Frame):
+
+        def __init__(self, parent):
+
+            wx.Frame.__init__(self, parent, -1, "SuperToolTip Demo")
+
+            panel = wx.Panel(self)
+            button = wx.Button(panel, -1, "I am the SuperToolTip target", pos=(100, 50))
+
+            tip = STT.SuperToolTip("A nice tooltip message")
+
+            tip.SetHeader("Hello World")
+            tip.SetTarget(button)
+            tip.SetDrawHeaderLine(True)
+
+            tip.ApplyStyle("Office 2007 Blue")
+
+            tip.SetDropShadow(True)
+
+
+    # our normal wxApp-derived class, as usual
+
+    app = wx.PySimpleApp()
+
+    frame = MyFrame(None)
+    app.SetTopWindow(frame)
+    frame.Show()
+
+    app.MainLoop()
+
+
+
Supported Platforms
===================

-SuperToolTip has been tested on the following platforms:
+L{SuperToolTip} has been tested on the following platforms:
* Windows (Windows XP).


@@ -75,9 +115,9 @@
License And Version
===================

-SuperToolTip is distributed under the wxPython license.
+L{SuperToolTip} is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 22 Jul 2011, 21.00 GMT
+Latest Revision: Andrea Gavana @ 17 Aug 2011, 15.00 GMT

Version 0.4
Tree
@@ -2,7 +2,7 @@
#
# Andrea Gavana, @ 07 October 2008
-# Latest Revision: 22 Jul 2011, 21.00 GMT
+# Latest Revision: 17 Aug 2011, 15.00 GMT
#
#